<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fa_IR">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>پرش به پی.دی.اف</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>بدون پیشنهاد</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>نادیده‌گرفتن کلمه</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>ناتوان در حذف</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>پاره‌ای از پرونده‌های کمکی نمی‌توانند حذف شوند. شاید اجازهٔ این کار را ندارید.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>پذیرش حذف پرونده</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>پرونده‌های کمکی که حذف می‌شوند:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>گزیدن همه</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>گزیدن هیچ‌کدام</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>جابجایی</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>پیدا کن</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>پیدا کن:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;بسته‌بندی</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>پیدا کردن &amp;پس‌گرد</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>جستجوی &amp;برگزیده</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>یافتن &amp;تمام موارد</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>جستجوی همهٔ &amp;پرونده‌های باز</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;حساس به بزرگی و کوچکی حروف</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>ه&amp;مهٔ کلمات</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>عبارت من&amp;ظم</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>بدون رشتهٔ جستجوی اخیر</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(بی‌ارزش)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>بسته‌بندی واقعی</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>خط‌ها را بسته‌بندی کن به:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>اندازهٔ پنجرهٔ جاری</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>درازی رج:</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>بسته‌بندی تازهٔ پاراگراف‌ها</translation>
    </message>
    <message>
        <source>Unwrap</source>
        <translation>از بسته‌بندی خارج کن</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>گشودن واپسین</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>ناتوان در بازگذاری پروندهٔ &quot;%1&quot;؛ شاید مستند پی‌دی‌اف باارزشی نیست.</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>دانستنی‌های همگام تک موجود نیست</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>همگام تک: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>برگهٔ %1 از %2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>untitled.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>کمک</translation>
    </message>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ویرایش</translation>
    </message>
    <message>
        <source>View</source>
        <translation>مشاهده</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>پنجره</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>نمایش</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>حروف‌چینی</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>جستجو</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>نوارابزار</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>دربارهٔ تک‌ورکس...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>برگهٔ نخست</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>برگهٔ پیش</translation>
    </message>
    <message>
        <source>Ctrl+PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>برگهٔ پسین</translation>
    </message>
    <message>
        <source>Ctrl+PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>برگهٔ پایانی</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>برو به برگهٔ ...</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>بزرگ‌نمایی</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>کوچک‌نمایی</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>پرکردن پنجره</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>اندازهٔ راستین</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>پرکردن پهنا</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>New</source>
        <translation>تازه</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>گشودن...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>بستن</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>چیدن</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>واچیدن</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>برداشتن</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>رونگاشت</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>چسباندن</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>پاک‌کردن</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation>Ctrl+Backspace</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>حروف‌چینی</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>ساماندهی...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>پشته‌ای</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>کاشی‌کاری</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>برو به سرچشمه</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>تازه از الگو...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>همهٔ برگه</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation>Ctrl+Shift+F</translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>بزرگ‌نمایی</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>لغزاندن</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>گزیدن متن</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>گزیدن فرتور</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>برو به برگهٔ خانگی تک‌ورکس</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>رایانامه به لیست رایانامه</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>پهلو به پهلو</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>گذاشتن در چپ</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>گذاشتن در راست</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>بیرون رفتن از تک‌ورکس</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>پیدا کن...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>دوباره پیدا کن</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>سند</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>سندسازی تک‌ورکس</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>بازخوانی لیست سندها</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>مدیریت سندها</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>نمایش پوشهٔ سندها</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>دربارهٔ سند...</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>چاپ پی‌دی‌اف...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>کنسل حروف‌چینی</translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>به سبب دشواریهای تکنیکی، با افسوس این ویراست از %1 توان چاپ پی‌دی‌اف را ندارد.
</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>برای چاپ، آیا می‌خواهید پرونده را در نمایشگر پیش‌نشان بگشایید؟</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation>(به یاد داشته باشید که آن را برای جلوگیری از دشواریهای دسترسی ببندید)</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>ساماندهی و سرچشمه‌ها...</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>پاک کردن پروندههای واپسین</translation>
    </message>
    <message>
        <source>Error initializing SyncTeX</source>
        <translation>ایراد در مقداردهی اولیهٔ سینک‌تک</translation>
    </message>
    <message>
        <source>Go to previous view</source>
        <translation>برو به نمایش پیش</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation></translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>تک برگ</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>تک برگ پیوسته</translation>
    </message>
    <message>
        <source>Two Pages Continuous</source>
        <translation>دو برگ پیوسته</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>پرش به کد</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>برو به برگهٔ</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>شمارهٔ برگه:</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom level:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>پیدا کن</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>بدون رشتهٔ جستجوی واپسین</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>در پی‌دی‌اف بیاب</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>بیاب:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;بسته‌بندی پیرامون</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>بیاب &amp;پسین</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>بیاب &amp;همهٔ نمونه‌ها</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;حساس به بزرگ و کوچکی واج</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>هم&amp;گام به سرچشمه</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>گزیدن پوشه</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>ابزار تازه</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>پیش‌نشان سیستم [%1]</translation>
    </message>
    <message>
        <source>None</source>
        <translation>هیچ‌کدام</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>ساماندهی تک‌ورکس</translation>
    </message>
    <message>
        <source>General</source>
        <translation>همگانی</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>آیکون‌ها کوچک</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>آیکون‌ها متوسط</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>آیکون‌ها بزرگ</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>نمایش نوشته همراه با آیکون‌ها</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>زمان اجرا، نمایش بده</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>نوشتار تهی تازه</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>الگوی گفتگوی گزینش</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>گفتگوی گشودن پرونده</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>ویرایشگر</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>پیش‌نشانهای ویرایشگر</translation>
    </message>
    <message>
        <source> pt</source>
        <translation>پوینت</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>پهنای تب:</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>شمارهٔ رج‌ها</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>بسته‌بندی رج‌ها</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>رنگ‌آمیزی  دستوری:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>حالت تورفتگی خودکار:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>زبان غلت‌گیر:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>رمزینه:</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>گزینه‌های سراسری ویرایشگر</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>پررنگ کردن رج کنونی</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>پیش‌نمایش</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>سنجهٔ پیش‌فرض</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>اندازهٔ درست</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>پرکردن پهنا</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>پرکردن پنجره</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>سنجهٔ استوار:</translation>
    </message>
    <message>
        <source> %</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>عدسی بزرگ‌نمایی</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>کوچک</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>میانه</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>بزرگ</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>بزرگ‌نمای گرد</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>دقت پرده:</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation type="obsolete">دی‌پی‌آی</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>حروف‌چینی</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>مسیر تک و برنامه‌های درپیوند</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>ابزارهای پردازش</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>ویرایش...</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>پیش‌نشان:</translation>
    </message>
    <message>
        <source> px</source>
        <translation>px</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>حالت بازگویی هوشمند:</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>سندها</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>امنیت</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>پروانهٔ خواندن تمام پرونده‌ها به سندها (سندها و پرونده‌های ساده همیشه خواندنی هستند)</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>پروانهٔ نوشتن فایل‌ها به سندها</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>پروانهٔ اجرای فرمان‌های سیستم به سندها</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>پویاسازی افزونهٔ زبان‌های سند (شاید تنگناهایی بر رفتار سندها انجام دهد)</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>اشکال زدایی</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>پویاسازی اشکال‌زایی QtScript</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>هیچگاه</translation>
    </message>
    <message>
        <source>Automatically</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>خودکار</translation>
    </message>
    <message>
        <source>On success</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>در صورت کامیابی</translation>
    </message>
    <message>
        <source>&lt;em&gt;Note:&lt;/em&gt; These are default settings. Changes to them will not affect windows that are already open. Use the respective items in the &amp;quot;Format&amp;quot; menu to achieve that.</source>
        <translation>&lt;em&gt;هشدار:&lt;/em&gt; اینها سامانه‌های پیش‌نشان هستند. دگرگونی آنها بر پنجره‌های باز نشان نمی‌گذارد.  برای دستیابی، گزینهٔ همسان را از منوی &amp;quot;شمایل&amp;quot; برگزینید.</translation>
    </message>
    <message>
        <source>Enable autocompletion</source>
        <translation>پویاسازی تکمیل خودکار</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>رابط</translation>
    </message>
    <message>
        <source>Locale:</source>
        <translation>بومی</translation>
    </message>
    <message>
        <source>Toolbar buttons:</source>
        <translation>کلیدهای نوارابزار:</translation>
    </message>
    <message>
        <source>Open corresponding PDF preview with TeX files</source>
        <translation>گشودن پی‌دی‌اف متناظر همراه با پروندهٔ تک</translation>
    </message>
    <message>
        <source>Hide console output:</source>
        <translation>پنهان‌سازی پیشانهٔ خروجی:</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;strong&gt;Never:&lt;/strong&gt; Never hide the console output panel after typesetting.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatically:&lt;/strong&gt; Hide the console output panel after successful typesetting, but only if it was hidden before.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;On Success:&lt;/strong&gt; Hide the console output panel after successful typesetting, regardless of its previous state.&lt;/p&gt;
</source>
        <translation>&lt;p&gt;&lt;strong&gt;هیچگاه:&lt;/strong&gt; هیچگاه پس از حروفچینی پنل خروجی را پنهان نکن.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;خودکار:&lt;/strong&gt; پس از حروفچینی پیروزمندانه پنل خروجی را پنهان کن: اما تنها زمانی که از پیش پنهان بوده باشد.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;در صورت پیروزمندانه بودن:&lt;/strong&gt;پنل خروجی را پس از حروفچینی پیروزمندانه پنهان کن؛ آزاد از اینکه از پیش چگونه بوده است.&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>Page mode:</source>
        <translation>حالت برگه:</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>تک برگ</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>تک برگ پیوسته</translation>
    </message>
    <message>
        <source>Two Page Continuous</source>
        <translation>دو برگ پیوسته</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>نوشتارهای تک (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>نوشتارهای لاتک (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>پایگاه داده‌های بیب‌تک (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>پرونده‌های سبکی (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>پرونده‌های کلاس (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>ماکروهای بازنموده (*.dtx)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>پرونده‌های نوشتاری (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>نوشتار پی‌دی‌اف (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>همهٔ پرونده‌ها</translation>
    </message>
    <message>
        <source>Log files (*.log *.blg)</source>
        <translation>پرونده‌های لاگ (*.log *.blg)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</source>
        <translation>پرونده‌های کمکی (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>جایگزینی</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>جایگزینی همه</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>کنسل</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>بدون رشتهٔ جستجوی واپسین</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>بدون رشتهٔ جایگزینی واپسین</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(بی‌ارزش)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>جایگزینی:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>با:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;بسته‌بندی درست</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>بیاب &amp;پیش‌گرد</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>جایگزینی با &amp;گزیده</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>جایگزینی در همه &amp;پرونده‌های باز</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;حساس به بزرگی و کوچکی واج‌ها</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>ه&amp;مهٔ واژه‌ها</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>گزارهٔ &amp;سازمند</translation>
    </message>
</context>
<context>
    <name>ResourcesDialog</name>
    <message>
        <source>TeXworks Settings and Resources</source>
        <translation>ساماندهی‌ها و سرچشمه‌های تک‌ورکس</translation>
    </message>
    <message>
        <source>Storage Locations</source>
        <translation>جایگاه ذخیره</translation>
    </message>
    <message>
        <source>Settings:</source>
        <translation>ساماندهی‌ها:</translation>
    </message>
    <message>
        <source>Resources:</source>
        <translation>سرچشمه‌ها:</translation>
    </message>
    <message>
        <source>Registry (%1)</source>
        <translation>دفتر نگارش (%1)</translation>
    </message>
</context>
<context>
    <name>ScreenCalibrationWidget</name>
    <message>
        <source>Drag the ruler or change the value to match real world lengths.
Common paper sizes are marked as well (you may need to resize the dialog window to see them).
Use the context menu to change the units.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> dpi</source>
        <extracomment>dots per inch</extracomment>
        <translation type="unfinished">دی‌پی‌آی</translation>
    </message>
    <message>
        <source>DIN A4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Letter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cm</source>
        <extracomment>this refers to the length unit of centimeters</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>in</source>
        <extracomment>this refers to the length unit of inches</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation>ساماندهی سندها</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>سند ناوابسته</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>سند لنگری</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>نام:</translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>نوشتار:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>بازنمود:</translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>نویسنده:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>ویراست:</translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>میان‌بر:</translation>
    </message>
    <message>
        <source>File: </source>
        <translation>پرونده:</translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>زبان:</translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>لنگر:</translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>رج</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>شروع</translation>
    </message>
    <message>
        <source>End</source>
        <translation>پایان</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نوشته</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>دستاورد جستجو</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>دستاورد جستجو - %1 (%2 پیدا شد)</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>New</source>
        <translation>تازه</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>تازه از الگو...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>ساماندهی‌ها...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>گشودن...</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>گشودن واپسین</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>کمک</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>برو به برگهٔ خانگی تک‌ورکس</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>ایمیل به لیست ایمیل</translation>
    </message>
    <message>
        <source>About </source>
        <translation>دربارهٔ</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;‏‫%1 فراگردی ساده برای نگارش، حروف‌چینی، و نمایش نوشتارهای تک است. ‬&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;کتابخانهٔ برگردان پی‌دی‌اف &lt;a href=&quot;http.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; بدست Kristian H&amp;#xF8;gsberg, Albert Astals Cid و دیگران.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;پنداره‌ها و سرچشمه‌ها از &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TexShop&lt;/a&gt; بدست Richard Koch.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;فناوری &lt;a href=&quot;http://itemac.sourceforge.net/SyncTex.html&quot;&gt;SyncTex&lt;/a&gt; بدست J&amp;#xE9;r&amp;#xF4;me Laurens.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;پاره‌ای از آیکون‌های بکار گرفته شده از پروژهٔ &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt; هستند.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt; پیشکش برگردان ‫%1 از %2‏.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>پارسی</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>مهدی امیدعلی/mehdioa@gmail.com</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>دربارهٔ %1</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>ناتوان در دسترسی به &quot;%1&quot;؛ شاید مرورگر و نرم‌افزار کاربردی ایمیل شما به‌درستی ساماندهی نشده است؟</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>ناتوان در ساختن پنجره</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>چیزی به‌شدت غلت است، %1 نتوانست پنجرهٔ نوشتار را بسازد. نرم‌افزار کاربردی بیرون می‌رود.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>گشودن پرونده</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>پوشهٔ باینری پیش‌نشان یافته نشد</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.&lt;/small&gt;</source>
        <translation>هیچ‌کدام از پوشه‌های شناسایی شده برای برنامه‌های درپیوند با تک پیدا نمی‌شوند. &lt;p&gt;&lt;small&gt;برای کاربست هر پردازشی، باید پوشه‌های باینری پخشایش تک خود را از گزینهٔ حروف‌چینی از گفتگوی ساماندهی‌ها ساماندهی کنید.&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>پروندهٔ کمکی یافت نشد.</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>ذخیرهٔ پرونده</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>درخواست پروانه</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>سند &quot;%1&quot;در حال گشودن پروندهٔ &quot;%2&quot; بدون پروانهٔ کافی است. آیا می‌خواهید پرونده را باز کنید؟</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2 or (at your option) any later version.</source>
        <translation>&lt;p&gt; پخش‌شده زیر &lt;a href=&quot;http://www.gnu.org/licences/gpl-2.0.html&quot;&gt; پروانهٔ سراسری گنو&lt;/a&gt;, ویراست ۲ یا ویراست‌های تازه‌تر .</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>پاککردن پروندههای واپسین</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2) [r.%3, %4]</source>
        <translation>&lt;br&gt;ویرایش %1 (%2) [r.%3, %4]</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2)</source>
        <translation>&lt;br&gt;ویرایش %1 (%2)</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>خروج از تک‌ورکس</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by The Qt Company.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;چارچوب کاربردی کیوت&lt;/a&gt; v%1 توسط کمپانی کیوت.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>خطای درونی</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>ناتوان در کاربست فرمان سیستم: %1</translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>خطا در کاربست فرمان سیستم:%1</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>کاربست فرمان سیستم ناممکن است ( ساماندهی‌ها را ببینید)</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>&quot;%1&quot; نمی‌تواند باز شود.</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>خواندن همهٔ پرونده‌ها نشدنی است (ساماندهی‌ها را ببینید)</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>پروندهٔ &quot;%1&quot; را برای خواندن نمی‌توان گشود</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>سند &quot;%1&quot;:%2</translation>
    </message>
    <message>
        <source>Script result</source>
        <translation>دستاورد سند</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>خطای ناشناخته</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>سند می‌تواند برای افزودن فرمان تازه به %1 ، یا گسترش و یا بهسازی آن بکار برده شود.</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>برای دانستن بیشتر در بارهٔ ساخت و استفاده از سندها به %1 بروید &lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>زبان‌های سند در دسترس در این ویراست از %1:</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>دربارهٔ سند</translation>
    </message>
    <message>
        <source>Script error</source>
        <translation>خطای اسکریپت</translation>
    </message>
    <message>
        <source>(disabled in the preferences)</source>
        <extracomment>This string is appended to a script language name to indicate it is currently disabled</extracomment>
        <translation>(ناپویا در تنظیم‌ها)</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>خطا: کد شکست %1</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>خطا: کد برون‌رفت %1</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>اتیکت‌ها</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>چوب‌خط‌ها</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>چهارچوب سراسری</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>بدون اتیکت</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>نوشتار تازه</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>گشودن واپسین</translation>
    </message>
    <message>
        <source>None</source>
        <translation>هیچ‌کدام</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>گشودن پرونده</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>ذخیرهٔ پرونده</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>نوشتار &quot;%1&quot; بازسازی شده است.
آیا می‌خواهید دگرگونی‌ها را ذخیره کنید؟</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>آیا می‌خواهید تمام دگرگونی‌های نوشتار &quot;%1&quot; را دور بیندازید، و به ویراست پایانی ذخیره‌شده برگردید؟</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>برگرداندن</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>رمزینهٔ ناشناخته</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>رمزینهٔ نوشتاری %1 بکاربرده شد در %2 پشتیبانی نمی‌شود.

به‌جای آن %3 را بکار گیرید، که شاید متن درست نمایش داده نشود.</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>پرونده روی دیسک دگرگون شد</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 توسط برنامهٔ دیگری بازسازی شده است.

آیا می‌خواهید دگرگونی‌های شما دور انداخته شود، و پرونده از دیسک فراخوانی شود؟</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 بدست برنامهٔ دیگری بازسازی شده است.

آیا می‌خواهید پرونده را در دیسک دوباره بنویسید؟</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>نوشتار &quot;%1&quot; ذخیره نشده است</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>متن تبدیل شدنی نیست</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>این نوشار دارای واج‌هایی است که در رمزینهٔ %1 نمایش‌پذیر نیست.

اگر ادامه دهید، این واج‌ها با اندازه‌های رمزینهٔ پیش‌نشان جایگزین می‌شوند. به‌جای این کار شاید بخواهید  رمزینهٔ دیگری مانند UTF-8 را بکار ببرید تا نوشته‌ها از دست نروند.</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>untitled-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>رج %1 از %2؛ ستون %3</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>برو به رج</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>شمارهٔ رج‌ها:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>گزارهٔ منظم بی‌ارزش</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>پیدا نشد</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>%n% نمونه پیدا شد
        </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n نمونه
        </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n نوشتار
        </numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>جایگزینی %1 در %2</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>جایگزینی %n نمونه
        </numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>نوشتار ذخیره نشده پردازش‌پذیر نیست</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>نوشتار ریشهٔ %1 خوانش‌پذیر نیست</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 به‌درستی تنظیم نشده است</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>ناتوان در کاربست %1</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>برنامهٔ %1 پیدا نشد.</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>جستجو در پوشه‌های:</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>پردازش بدست کابر ایست شد</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>ساماندهی موتور به %1</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>موتور &quot;%1&quot; شناسانده نشده است</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>پرونده‌ای پیدا نشد</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>هیچ پروندهٔ کمکی درپیوند با این نوشتار اکنون پیدا نشد.</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>untitled.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>پرونده</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ویرایش</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>بررسی املا</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>دگرش بزرگی و کوچکی واج‌ها</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>حروف‌چین</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>پنجره</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>نمایش</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>جستجو</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>شمایل</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>گونهٔ تورفتگی خودکار</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>رنگ‌آمیزی  دستوری</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>بازگویی هوشمند</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>کمک</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>نوارابزار حروف‌چینی</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>نوارابزار ویرایش</translation>
    </message>
    <message>
        <source>New</source>
        <translation>تازه</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>گشودن...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>بستن</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ذخیره</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>ذخیره بانام...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>برگرداندن به ذخیره شده</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>چیدن</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>واچیدن</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>برداشتن</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>رونگاشت</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>چسباندن</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>پاک‌کردن</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>حروف‌چینی</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>پیدا کن...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>دوباره پیدا کن</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>جایگزینی...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>ذخیره در پیدا شده</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>ذخیره در جایگزین شده</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>برو به رج...</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>گزیده را پیدا کن</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>گزینش همه</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>قلم...</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>تورفتگی</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation>Ctrl+]</translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>بدون تورفتگی</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation>Ctrl+[</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>بازنمود</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation>Ctrl+Shift+]</translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>برون از بازنمود</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation>Ctrl+Shift+[</translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>بسته‌بندی رج‌ها</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>دربارهٔ تک‌ورکس...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>پشته‌ای</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>کاشی‌کاری</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>ساماندهی‌ها...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>برو به پیش‌نمایش</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation>Ctrl+\</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>تازه از الگو...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>نمایش برگزیده</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>همهٔ واج‌ها بزرگ</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>همهٔ واج‌ها کوچک</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>همسنگی حائل‌ها</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>برو به برگهٔ خانگی تک‌ورکس</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>رایانامه به لیست رایانامه</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>پهلو به پهلو</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>گذاردن در چپ</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>گذاردن در راست</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>جایگزینی دوباره</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>زدودن پرونده‌های کمکی...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>برونرفت از تک‌ورکس</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Qtrl+Q</translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>جابجایی بزرگی و کوچکی واج‌ها</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>بسته‌بندی درست...</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>شمارهٔ رج‌ها</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>پیشانه برونی</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>سندها</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>سندسازی تک‌ورکس</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>نمایش پوشهٔ سندها</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>بازخوانی لیست سندها</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>ساماندهی سندها</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>دنبالگر کانونی خودکار</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>دربارهٔ سند...</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>بکاربستن بر برگزیده</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>ذخیره همه</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>ناتوان در خواندن پروندهٔ &quot;%1&quot;:
%2</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>پروندهٔ &quot;%1&quot; بارگذاری شد</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>%1 بدست برنامهٔ دیگری همواره دگرگون می‌شود.

بعد از پایان پردازش، خواهشمندم از «پرونده &gt; بازگردانی به ذخیره شده»  به صورت دستی استفاده کنید.</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>ناتوان از نوشتن پروندهٔ &quot;%1&quot;
%2</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>خطا در نوشتن پرونده</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>خطایی در هنگام نوشتن پرونده رخ داد. ممکن است بخواهید یک نسخه از پرونده را در جای دیگری ذخیره کنید.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>پروندهٔ &quot;%1&quot; ذخیره شد</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>کنسل‌کردن حروف‌چینی</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>ساماندهی‌ها و سرچشمه‌ها...</translation>
    </message>
    <message>
        <source>Reload using selected encoding</source>
        <extracomment>Item in the encoding popup menu</extracomment>
        <translation>بازخوانی بر اساس رمزینهٔ برگزیده</translation>
    </message>
    <message>
        <source>Reloads the current file with the encoding selected from this menu.

The selected encoding replaces the default one and overrides all &quot;%!TEX encoding&quot; lines.</source>
        <extracomment>Tooltip for &quot;Reload using selected encoding&quot;</extracomment>
        <translation> بازخوانی پروندهٔ کنونی با رمزینهٔ برگزیده از این منو.

 رمزینهٔ برگزیده جایگزین رمزینهٔ پیش‌نشان شد  &quot;%!TEX encoding&quot; رج‌های.</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>دگرگونی‌های ذخیره‌نشده</translation>
    </message>
    <message>
        <source>The file you are trying to reload has unsaved changes.

Do you want to discard your current changes, and reload the file from disk with the encoding %1?</source>
        <translation>پرونده‌ای را که می‌خواهید بازخوانی کنید دارای دگرگونی‌های ذخیره نشده است.

آیا می‌خواهید دگرگونی‌های کنونی را دوربریزید، و پرونده را با رمزینهٔ %1 از دیسک بازخوانی کنید؟</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>پاک‌کردن پرونده‌های واپسین</translation>
    </message>
    <message>
        <source>Abort typesetting?</source>
        <translation>کنسل‌کردن حروف‌چینی؟</translation>
    </message>
    <message>
        <source>A typesetting process is still running and must be stopped before closing this window.
Do you want to stop it now?</source>
        <translation>یک پردازش حروف‌چینی هنوز در حال کار است و پیش از بستن این پنجره بایدبایستد. 
آیا می‌خواهید آن رابایستانید؟</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>نیاز به &lt;b&gt;TeX پخشایشی از تک&lt;/b&gt; مانند &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;تک‌لایو&lt;/a&gt; یا &lt;a href=&quot;http://miktex.org/&quot;&gt;میک‌تک&lt;/a&gt; دارید که بر سیستم شما نصب شده باشد تا بتوانید نوشتهٔ خود را حروف‌چینی کنید. </translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>نیاز به &lt;b&gt;TeX پخشایشی از تک&lt;/b&gt; مانند &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;تک‌لایو&lt;/a&gt; یا &lt;a href=&quot;http://miktex.org/&quot;&gt;میک‌تک&lt;/a&gt; دارید که بر سیستم شما نصب شده باشد تا بتوانید نوشتهٔ خود را حروف‌چینی کنید. </translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; installed on your system to typeset your document. On most systems such a TeX distribution is available as prebuilt package.</source>
        <translation>نیاز به &lt;b&gt;TeX پخشایشی از تک&lt;/b&gt; مانند &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;تک‌لایو&lt;/a&gt; یا &lt;a href=&quot;http://miktex.org/&quot;&gt;میک‌تک&lt;/a&gt; دارید که بر سیستم شما نصب شده باشد تا بتوانید نوشتهٔ خود را حروف‌چینی کنید. بر بیشتر سیستم‌ها چنین پخشایشی از پیش نصب است.</translation>
    </message>
    <message>
        <source>When a TeX distribution is installed you may need to tell TeXworks where to find it in Edit -&gt; Preferences -&gt; Typesetting.</source>
        <translation>زمانی که پخشایشی از تک را نصب کردید، باید به تک‌ورکس بگویید که در کجا آن را بیابید در ویرایش-&gt;ساماندهی‌ها-&gt;حروف‌چینی.</translation>
    </message>
    <message>
        <source>Check the configuration of the %1 tool and the path settings in the Preferences dialog.</source>
        <translation>پیکربندی ابزار %1 و مسیر ساماندهی‌ها را در گفتگوی ساماندهی‌ها بررسی کنید. </translation>
    </message>
    <message>
        <source>Hide Console Output</source>
        <translation>پنهان‌سازی پیشانهٔ خروجی</translation>
    </message>
    <message>
        <source>Layout Problem</source>
        <translation>خطای چهارچوب</translation>
    </message>
    <message>
        <source>A problem occured while laying out the loaded document in the editor. This is caused by an issue in the underlying Qt framework and can cause TeXworks to crash under certain circumstances. The symptoms of this problem are hidden or overlapping lines. To work around this, please try one of the following:
 -) Turn syntax highlighting off and on
 -) Turn line numbers off and on
 -) Resize the window

We are sorry for the inconvenience.</source>
        <translation>مشکلی در قالب‌بندی نوشتار هنگام نمایش در ویرایشگر پدید آمد. این مشکل به خاطر ایرادی در چهارچوب زمینهٔ QT پدید آمد و ممکن است در شرایطی باعث درهم شکستن تک‌ورکس شود. دلیل این مشکل خط‌های پنهان یا هم‌پوشان است. برای برطرف کردن مشکل لطفاً یکی از کارهای زیر را انجام دهید:
-) رنگ‌آمیزی نحوی را پویا و ناپویا کنید
-)نمایش شمارهٔ خط‌ها را پویا و ناپویا کنید
-) پنجره را تغییر اندازه دهید

به خاطر مشکل پدید آمده پوزش می‌خواهیم.</translation>
    </message>
    <message>
        <source>Show Console Output</source>
        <translation>نمایش پیشانهٔ خروجی</translation>
    </message>
    <message>
        <source>Write UTF-8 byte order mark</source>
        <translation>نوشتن نشانهٔ بایت مرتبهٔ UTF-8</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>پیش‌نشان</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>پروندهٔ تازه از روی الگو</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>الگوی پروندهٔ تازه را برگزینید:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>گزینهٔ تازه</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation>گزینش پروندهٔ برنامه</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>برنامهٔ بی‌ارزش</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>پروندهٔ &apos;%1&apos; کاربستی نیست!</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>پیکربندی ابزار</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>نام:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>برنامه:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>گزینه‌ها:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>مشاهدهٔ پی‌دی‌اف پس از کاربست</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>بازبینی (جستجو)...</translation>
    </message>
</context>
</TS>
